import React, { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import axios from "axios";
import styles from "./EditUserDetailsStyles.module.css";

const EditUserDetails = () => {
  const { personId } = useParams();
  const [personDetails, setPersonDetails] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const fetchPersonDetails = async () => {
      setLoading(true);
      setError(null);

      try {
        const response = await axios.get(
          `${process.env.REACT_APP_API_URL}/person/fullInfo/${personId}`
        );
        setPersonDetails(response.data.person);
      } catch (err) {
        setError(
          err.response?.data?.message || "Failed to fetch user details."
        );
      } finally {
        setLoading(false);
      }
    };

    fetchPersonDetails();
  }, [personId]);

  if (loading) return <p>Loading user details...</p>;
  if (error) return <p className={styles.error}>{error}</p>;

  return (
    <div className={styles.container}>
      <h2>
        These are the user details, here you need to edit this user and use
        these details as initial values
      </h2>
      <p>
        <strong>Person ID:</strong> {personId}
      </p>
      <div className={styles.details}>
        <p>
          <strong>First Name:</strong>{" "}
          {personDetails.personalInformation.firstName}
        </p>
        <p>
          <strong>Last Name:</strong>{" "}
          {personDetails.personalInformation.lastName}
        </p>
        <p>
          <strong>Middle Name:</strong>{" "}
          {personDetails.personalInformation.middleName || "N/A"}
        </p>
        <p>
          <strong>Nick Name:</strong>{" "}
          {personDetails.personalInformation.nickName || "N/A"}
        </p>
        <p>
          <strong>Class Year:</strong>{" "}
          {personDetails.personalInformation.classYear}
        </p>
        <p>
          <strong>Graduation Year:</strong>{" "}
          {personDetails.personalInformation.gradYear}
        </p>
        <p>
          <strong>Gender:</strong> {personDetails.personalInformation.gender}
        </p>
        <p>
          <strong>Tech Alumni Chapter:</strong>{" "}
          {personDetails.personalInformation.techAlumniChapter}
        </p>
      </div>
    </div>
  );

  return (
    <div>
      <p>User details for user:</p>
      <p>personId</p>
    </div>
  );
};

export default EditUserDetails;
